@@ -32,7 +32,7 @@
  */
 #define DQLITE_VERSION_MAJOR 1
 #define DQLITE_VERSION_MINOR 18
-#define DQLITE_VERSION_RELEASE 2
+#define DQLITE_VERSION_RELEASE 5
 #define DQLITE_VERSION_NUMBER                                            \
 	(DQLITE_VERSION_MAJOR * 100 * 100 + DQLITE_VERSION_MINOR * 100 + \
 	 DQLITE_VERSION_RELEASE)
@@ -42,6 +42,8 @@
 
 DQLITE_API int dqlite_version_number(void);
 
+DQLITE_API extern const char *dqlite_version_string;
+
 /**
  * Hold the value of a dqlite node ID. Guaranteed to be at least 64-bit long.
  */
@@ -452,16 +454,6 @@ DQLITE_API int dqlite_node_set_snapshot_params_v2(dqlite_node *n,
  */
 DQLITE_API int dqlite_node_set_block_size(dqlite_node *n, size_t size);
 
-/**
- * WARNING: This is an experimental API.
- *
- * By default dqlite holds the SQLite database file and WAL in memory. By
- * enabling disk-mode, dqlite will hold the SQLite database file on-disk while
- * keeping the WAL in memory. Has to be called after `dqlite_node_create` and
- * before `dqlite_node_start`.
- */
-DQLITE_API int dqlite_node_enable_disk_mode(dqlite_node *n);
-
 /**
  * Set the target number of voting nodes for the cluster.
  *
